@@ -171,7 +171,7 @@ void DynamicWallpaperModelPrivate::internalScheduleRemove(const QModelIndex &ind
     if (wallpapers[row]->isZombie == set)
         return;
     wallpapers[row]->isZombie = set;
-    emit q->dataChanged(index, index, { DynamicWallpaperModel::WallpaperIsZombieRole });
+    Q_EMIT q->dataChanged(index, index, { DynamicWallpaperModel::WallpaperIsZombieRole });
 }
 
 void DynamicWallpaperModelPrivate::internalRemove(const QModelIndex &index)
@@ -332,7 +332,7 @@ void DynamicWallpaperModelPrivate::loadGenericWallpapers()
     // Load the package structure in the main thread because it seems like the PackageLoader
     // class is not thread-safe. Notice that system wallpapers are discovered in another thread
     // since we may need to read file contents in order to determine whether a given file is
-    // actually a dynamic wallpaper and not just some random heif file.
+    // actually a dynamic wallpaper and not just some random avif file.
     KPackage::PackageStructure *packageStructure =
             KPackage::PackageLoader::self()->loadPackageStructure(QStringLiteral("Wallpaper/Dynamic"));
 
@@ -506,7 +506,7 @@ void DynamicWallpaperModel::handleProberFinished(const QUrl &fileUrl)
 
 void DynamicWallpaperModel::handleProberFailed(const QUrl &fileUrl)
 {
-    emit errorOccurred(i18n("%1 is not a dynamic wallpaper", fileUrl.toLocalFile()));
+    Q_EMIT errorOccurred(i18n("%1 is not a dynamic wallpaper", fileUrl.toLocalFile()));
 }
 
 /*!
