@@ -6,7 +6,6 @@
 
 #include "dynamicwallpaperprober.h"
 
-#include <KDynamicWallpaperMetaData>
 #include <KDynamicWallpaperReader>
 
 /*!
@@ -41,12 +40,10 @@ DynamicWallpaperProber::~DynamicWallpaperProber()
 void DynamicWallpaperProber::run()
 {
     const KDynamicWallpaperReader reader(m_fileUrl.toLocalFile());
-    const KDynamicWallpaperMetaData metadata = reader.metaDataAt(0);
-
-    if (metadata.isValid())
-        emit finished(m_fileUrl);
+    if (reader.error() == KDynamicWallpaperReader::NoError)
+        Q_EMIT finished(m_fileUrl);
     else
-        emit failed(m_fileUrl);
+        Q_EMIT failed(m_fileUrl);
 
     deleteLater();
 }
